==> kubernetes-model-policy-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/PodDisruptionBudgetBuilder.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodDisruptionBudgetBuilder extends PodDisruptionBudgetFluentImpl<PodDisruptionBudgetBuilder> implements VisitableBuilder<PodDisruptionBudget,PodDisruptionBudgetBuilder>{
  public PodDisruptionBudgetBuilder() {
    this(false);
  }
  public PodDisruptionBudgetBuilder(Boolean validationEnabled) {
    this(new PodDisruptionBudget(), validationEnabled);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudgetFluent<?> fluent) {
    this(fluent, false);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudgetFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodDisruptionBudget(), validationEnabled);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudgetFluent<?> fluent,PodDisruptionBudget instance) {
    this(fluent, instance, false);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudgetFluent<?> fluent,PodDisruptionBudget instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudget instance) {
    this(instance,false);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudget instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodDisruptionBudgetFluent<?> fluent;
  Boolean validationEnabled;
  public PodDisruptionBudget build() {
    PodDisruptionBudget buildable = new PodDisruptionBudget(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-policy-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/PodDisruptionBudgetBuilder.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodDisruptionBudgetBuilder extends PodDisruptionBudgetFluent<PodDisruptionBudgetBuilder> implements VisitableBuilder<PodDisruptionBudget,PodDisruptionBudgetBuilder>{
  public PodDisruptionBudgetBuilder() {
    this(false);
  }
  public PodDisruptionBudgetBuilder(Boolean validationEnabled) {
    this(new PodDisruptionBudget(), validationEnabled);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudgetFluent<?> fluent) {
    this(fluent, false);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudgetFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodDisruptionBudget(), validationEnabled);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudgetFluent<?> fluent,PodDisruptionBudget instance) {
    this(fluent, instance, false);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudgetFluent<?> fluent,PodDisruptionBudget instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PodDisruptionBudget());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudget instance) {
    this(instance,false);
  }
  public PodDisruptionBudgetBuilder(PodDisruptionBudget instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PodDisruptionBudget());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodDisruptionBudgetFluent<?> fluent;
  Boolean validationEnabled;
  public PodDisruptionBudget build() {
    PodDisruptionBudget buildable = new PodDisruptionBudget(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
